podmutating

package
v0.0.0-...-6bf25c0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 9, 2026 License: Apache-2.0 Imports: 16 Imported by: 0

Documentation

Overview

* Copyright (c) 2023 Baidu, Inc. All Rights Reserved. * * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file * except in compliance with the License. You may obtain a copy of the License at * * http://www.apache.org/licenses/LICENSE-2.0 * * Unless required by applicable law or agreed to in writing, software distributed under the * License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, * either express or implied. See the License for the specific language governing permissions * and limitations under the License. *

Index

Constants

This section is empty.

Variables

var (
	// HandlerMap contains admission webhook handlers
	HandlerMap = map[string]admission.Handler{
		"mutating-pod": &MutatingPodHandler{},
	}
)

Functions

func RegisterCustomerFlags

func RegisterCustomerFlags(pset *pflag.FlagSet)

Types

type MutatingPodHandler

type MutatingPodHandler struct {

	// Decoder decodes objects
	Decoder *admission.Decoder
	// contains filtered or unexported fields
}

func (*MutatingPodHandler) Handle

Handle handles admission requests.

func (*MutatingPodHandler) InjectDecoder

func (h *MutatingPodHandler) InjectDecoder(d *admission.Decoder) error

InjectDecoder injects the decoder into the PodCreateHandler

type PatchOperation

type PatchOperation struct {
	Op    string      `json:"op"`
	Path  string      `json:"path"`
	Value interface{} `json:"value,omitempty"`
}

PatchOperation - JSON Patch operation struct

Jump to