Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type SubnetLister ¶
type SubnetLister interface {
// List lists all Subnets in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1.Subnet, err error)
// Get retrieves the Subnet from the index for a given name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1.Subnet, error)
SubnetListerExpansion
}
SubnetLister helps list Subnets. All objects returned here must be treated as read-only.
func NewSubnetLister ¶
func NewSubnetLister(indexer cache.Indexer) SubnetLister
NewSubnetLister returns a new SubnetLister.
type SubnetListerExpansion ¶
type SubnetListerExpansion interface{}
SubnetListerExpansion allows custom methods to be added to SubnetLister.
Click to show internal directories.
Click to hide internal directories.