Documentation
¶
Overview ¶
* Copyright (c) 2023 Baidu, Inc. All Rights Reserved. * * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file * except in compliance with the License. You may obtain a copy of the License at * * http://www.apache.org/licenses/LICENSE-2.0 * * Unless required by applicable law or agreed to in writing, software distributed under the * License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, * either express or implied. See the License for the specific language governing permissions * and limitations under the License. *
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // HandlerMap contains admission webhook handlers HandlerMap = map[string]admission.Handler{ "mutating-pod": &MutatingPodHandler{}, } )
Functions ¶
func RegisterCustomerFlags ¶
Types ¶
type MutatingPodHandler ¶
type MutatingPodHandler struct {
// Decoder decodes objects
Decoder *admission.Decoder
// contains filtered or unexported fields
}
func (*MutatingPodHandler) InjectDecoder ¶
func (h *MutatingPodHandler) InjectDecoder(d *admission.Decoder) error
InjectDecoder injects the decoder into the PodCreateHandler
type PatchOperation ¶
type PatchOperation struct {
Op string `json:"op"`
Path string `json:"path"`
Value interface{} `json:"value,omitempty"`
}
PatchOperation - JSON Patch operation struct